# eric7.Templates.TemplatePropertiesDialog

Module implementing the templates properties dialog.

### Global Attributes

None

### Classes

TemplatePropertiesDialog | Class implementing the templates properties dialog.

### Functions

None

## TemplatePropertiesDialog

Class implementing the templates properties dialog.

### Derived from

QDialog, Ui_TemplatePropertiesDialog

### Class Attributes

None

### Class Methods

None

### Methods

TemplatePropertiesDialog | Constructor
getData | Public method to get the data entered into the dialog.
keyPressEvent | Protected method to handle the user pressing the escape key.
on_helpButton_clicked | Private slot to show some help.
setSelectedGroup | Public method to select a group.

### Static Methods

None

#### TemplatePropertiesDialog (Constructor)

TemplatePropertiesDialog(parent, groupMode=False, itm=None)

Constructor

parent (QWidget)
  the parent widget
groupMode (bool)
  flag indicating group mode
itm (TemplateEntry or TemplateGroup)
  item to read the data from

#### TemplatePropertiesDialog.getData

getData()

Public method to get the data entered into the dialog.

Return:
  a tuple containing the name and language, if the dialog is in group mode, or a tuple containing the name, description, group name and template otherwise.

Return Type:
  tuple of (str, str) or tuple of (str, str, str, str)

#### TemplatePropertiesDialog.keyPressEvent

keyPressEvent(ev)

Protected method to handle the user pressing the escape key.

ev (QKeyEvent)
  key event

#### TemplatePropertiesDialog.on_helpButton_clicked

on_helpButton_clicked()

Private slot to show some help.

#### TemplatePropertiesDialog.setSelectedGroup

setSelectedGroup(name)

Public method to select a group.

name (str)
  name of the group to be selected

Up